package SoE is

   --  any range limit you like
   Limit : constant Positive := 50;

   type Container_T is array (1 .. Limit) of Integer;

   --+------------------------------
   --  a protected resource type that shall hold
   --+ the integer values exchanged by sibling instances
   --+ of the Sieve process
   --+------------------------------
   protected type Buffer_T is
      entry Put (Item :        Integer);
      entry Get (Item :    out Integer);
   private
      A_Container : Container_T;
      Insert,
      Extract     : Positive := 1;
      Contents    : Natural  := 0;
   end Buffer_T;
   --+------------------------------

   --  the process that will pass all the odd numbers
   --+ in the given interval on to the chain of instances
   --+ of the Sieve process for them to analyze
   --+--------------------------------
   task Odd;
   --+--------------------------------

   --  the type of the Sieve processes
   --+ with 2 discriminant values that will be initialized
   --+ at the time of construction
   --+--------------------------------
   task type Sieve_T
     (Buf : access Buffer_T;
      Id  : Positive);
   type Sieve_Ref_T is access Sieve_T;
   --  we now declare a fully equivalent task type, but by a different name
   --+ which we need to avoid using Sieve_T as the task type name
   --+ in the instantiation from a task object of that type
   subtype Sibling_T is Sieve_T;
   --+--------------------------------

end SoE;
